Search Linux Wireless

[PATCH] zd1211rw-mac80211: prefix zd_op_ for mac80211 operations

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



From: Ulrich Kunitz <kune@xxxxxxxxxxxxxx>

zd_mac.c has used the prefix zd_mac_ for extern function as well
for the static mac80211 operations. This patch introduces the
prefix zd_op_ for the mac80211 operations for more clarity. There
has been no functional change been implemented.

Signed-off-by: Ulrich Kunitz <kune@xxxxxxxxxxxxxx>
Signed-off-by: Daniel Drake <dsd@xxxxxxxxxx>
---
 drivers/net/wireless/zd1211rw-mac80211/zd_mac.c |   34 +++++++++++-----------
 1 files changed, 17 insertions(+), 17 deletions(-)

diff --git a/drivers/net/wireless/zd1211rw-mac80211/zd_mac.c b/drivers/net/wireless/zd1211rw-mac80211/zd_mac.c
index 1c16f66..1693532 100644
--- a/drivers/net/wireless/zd1211rw-mac80211/zd_mac.c
+++ b/drivers/net/wireless/zd1211rw-mac80211/zd_mac.c
@@ -195,7 +195,7 @@ static int set_mc_hash(struct zd_mac *mac)
 	return zd_chip_set_multicast_hash(&mac->chip, &hash);
 }
 
-static int zd_mac_open(struct ieee80211_hw *hw)
+static int zd_op_open(struct ieee80211_hw *hw)
 {
 	struct zd_mac *mac = zd_hw_mac(hw);
 	struct zd_chip *chip = &mac->chip;
@@ -279,7 +279,7 @@ static void kfree_tx_skb(struct sk_buff *skb)
 	dev_kfree_skb_any(skb);
 }
 
-static int zd_mac_stop(struct ieee80211_hw *hw)
+static int zd_op_stop(struct ieee80211_hw *hw)
 {
 	struct zd_mac *mac = zd_hw_mac(hw);
 	struct zd_chip *chip = &mac->chip;
@@ -555,7 +555,7 @@ static int fill_ctrlset(struct zd_mac *mac,
 }
 
 /**
  * zd_mac_tx - transmits a network frame to the device
  *
  * @dev: mac80211 hardware device
  * @skb: socket buffer
@@ -565,7 +565,7 @@ static int fill_ctrlset(struct zd_mac *mac,
  * control block of the skbuff will be initialized. If necessary the incoming
  * mac80211 queues will be stopped.
  */
-static int zd_mac_tx(struct ieee80211_hw *hw, struct sk_buff *skb,
+static int zd_op_tx(struct ieee80211_hw *hw, struct sk_buff *skb,
 		     struct ieee80211_tx_control *control)
 {
 	struct zd_mac *mac = zd_hw_mac(hw);
@@ -697,7 +697,7 @@ int zd_mac_rx(struct ieee80211_hw *hw, const u8 *buffer, unsigned int length)
 	return 0;
 }
 
-static int zd_mac_add_interface(struct ieee80211_hw *hw,
+static int zd_op_add_interface(struct ieee80211_hw *hw,
 				struct ieee80211_if_init_conf *conf)
 {
 	struct zd_mac *mac = zd_hw_mac(hw);
@@ -720,20 +720,20 @@ static int zd_mac_add_interface(struct ieee80211_hw *hw,
 	return 0;
 }
 
-static void zd_mac_remove_interface(struct ieee80211_hw *hw,
+static void zd_op_remove_interface(struct ieee80211_hw *hw,
 				    struct ieee80211_if_init_conf *conf)
 {
 	struct zd_mac *mac = zd_hw_mac(hw);
 	mac->type = IEEE80211_IF_TYPE_MGMT;
 }
 
-static int zd_mac_config(struct ieee80211_hw *hw, struct ieee80211_conf *conf)
+static int zd_op_config(struct ieee80211_hw *hw, struct ieee80211_conf *conf)
 {
 	struct zd_mac *mac = zd_hw_mac(hw);
 	return zd_chip_set_channel(&mac->chip, conf->channel);
 }
 
-static int zd_mac_config_interface(struct ieee80211_hw *hw, int if_id,
+static int zd_op_config_interface(struct ieee80211_hw *hw, int if_id,
 				   struct ieee80211_if_conf *conf)
 {
 	struct zd_mac *mac = zd_hw_mac(hw);
@@ -757,7 +757,7 @@ static void set_multicast_hash_handler(struct work_struct *work)
 	zd_chip_set_multicast_hash(&mac->chip, &hash);
 }
 
-static void zd_mac_set_multicast_list(struct ieee80211_hw *hw,
+static void zd_op_set_multicast_list(struct ieee80211_hw *hw,
 				      unsigned short dev_flags, int mc_count)
 {
 	struct zd_mc_hash hash;
@@ -786,14 +786,14 @@ static void zd_mac_set_multicast_list(struct ieee80211_hw *hw,
 }
 
 static const struct ieee80211_ops zd_ops = {
-	.tx			= zd_mac_tx,
-	.open			= zd_mac_open,
-	.stop			= zd_mac_stop,
-	.add_interface		= zd_mac_add_interface,
-	.remove_interface	= zd_mac_remove_interface,
-	.config			= zd_mac_config,
-	.config_interface	= zd_mac_config_interface,
-	.set_multicast_list	= zd_mac_set_multicast_list
+	.tx			= zd_op_tx,
+	.open			= zd_op_open,
+	.stop			= zd_op_stop,
+	.add_interface		= zd_op_add_interface,
+	.remove_interface	= zd_op_remove_interface,
+	.config			= zd_op_config,
+	.config_interface	= zd_op_config_interface,
+	.set_multicast_list	= zd_op_set_multicast_list
 };
 
 struct ieee80211_hw *zd_mac_alloc_hw(struct usb_interface *intf)
@@ -555,7 +555,7 @@ static int fill_ctrlset(struct zd_mac *mac,
 
 /**
- * zd_mac_tx - transmits a network frame to the device
+ * zd_op_tx - transmits a network frame to the device
  *
  * @dev: mac80211 hardware device
-- 
1.5.2.4

-
To unsubscribe from this list: send the line "unsubscribe linux-wireless" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Linux Host AP]     [ATH6KL]     [Linux Bluetooth]     [Linux Netdev]     [Kernel Newbies]     [Linux Kernel]     [IDE]     [Security]     [Git]     [Netfilter]     [Bugtraq]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux ATA RAID]     [Samba]     [Device Mapper]
  Powered by Linux